module REXML
	VERSION_MAJOR = 1
	VERSION_MINOR = 2
	RELEASE = 1
	# This taken directly from Jim Menard's NQXML.  Good idea, Jim.
	Version = "#{VERSION_MAJOR}.#{VERSION_MINOR}.#{RELEASE}"
	Copyright = 'Copyright  2001 Sean Russell <ser@germane-software.com>'
	Date = "*2001-340"
end
